==> haskell-hslua-module-doclayout-1.1.0-108-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.0
visibility:           public
id:                   hslua-module-doclayout-1.1.0-3zvUPWEy7rKEtqKSTDqjGE
key:                  hslua-module-doclayout-1.1.0-3zvUPWEy7rKEtqKSTDqjGE
license:              MIT
copyright:            © 2020-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  85e9fb18b53c552facc8fdc3760e164a
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.0-3zvUPWEy7rKEtqKSTDqjGE
depends:
    base-4.17.2.1 doclayout-0.4.0.1-11YGqkWIg6qGXOFUIr62uJ
    hslua-2.3.0-HZWPRE5ZSgFF7BGmWf7jHj text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-doclayout-1.1.0-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.0
visibility:           public
id:                   hslua-module-doclayout-1.1.0-EkQpIfsiJES7RAeltwKynF
key:                  hslua-module-doclayout-1.1.0-EkQpIfsiJES7RAeltwKynF
license:              MIT
copyright:            © 2020-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  5bcdebf097892204efa83c1076a8b136
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-doclayout-1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.0-EkQpIfsiJES7RAeltwKynF
depends:
    base-4.17.2.1 doclayout-0.4.0.1-AoLrWnaLzFeJVnYn27v1AZ
    hslua-2.3.0-JgJQrQ3CoiM8S9wpadYmbj text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
